notebook: Jupyter notebook, a web-based notebook environment for interactive computing
======================================================================================

Description
-----------

The Jupyter HTML notebook is a web-based notebook environment for
interactive computing.
